@@ -1,5 +1,6 @@
 /* ISC license. */
 
+#include <fcntl.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <stdint.h>
@@ -10,6 +11,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <regex.h>
+
 #include <skalibs/posixplz.h>
 #include <skalibs/uint64.h>
 #include <skalibs/types.h>
@@ -31,9 +33,10 @@
 #include <skalibs/siovec.h>
 #include <skalibs/skamisc.h>
 #include <skalibs/environ.h>
+
 #include <execline/config.h>
 
-#define USAGE "s6-log [ -q | -v ] [ -b ] [ -p ] [ -t ] [ -e ] [ -l linelimit ] logging_script"
+#define USAGE "s6-log [ -d notif ] [ -q | -v ] [ -b ] [ -p ] [ -t ] [ -e ] [ -l linelimit ] logging_script"
 #define dieusage() strerr_dieusage(100, USAGE)
 #define dienomem() strerr_diefu1sys(111, "stralloc_catb")
 
@@ -611,9 +614,9 @@ static inline void logdir_init (unsigned int index, uint32_t s, uint32_t n, uint
   if (finish(ldp, "current", 'u') < 0)
     strerr_diefu2sys(111, "finish current .u for logdir ", ldp->dir) ;
   memcpy(x + dirlen + 1, "state", 6) ;
-  ldp->fd = open_trunc(x) ;
-  if (ldp->fd < 0) strerr_diefu2sys(111, "open_trunc ", x) ;
-  fd_close(ldp->fd) ;
+  r = open_trunc(x) ;
+  if (r == -1) strerr_diefu2sys(111, "open_trunc ", x) ;
+  fd_close(r) ;
   st.st_size = 0 ;
   memcpy(x + dirlen + 1, "current", 8) ;
  opencurrent:
@@ -783,7 +786,7 @@ static inline void script_secondpass (char const *const *argv, scriptelem_t *scr
         sel_t selitem = { .type = (*argv)[0] != 'f' ? (*argv)[0] == '+' ? SELTYPE_PLUS : SELTYPE_MINUS : SELTYPE_DEFAULT } ;
         if ((*argv)[0] != 'f')
         {
-          int r = regcomp(&selitem.re, *argv + 1, REG_EXTENDED | REG_NOSUB | REG_NEWLINE) ;
+          int r = skalibs_regcomp(&selitem.re, *argv + 1, REG_EXTENDED | REG_NOSUB | REG_NEWLINE) ;
           if (r == REG_ESPACE)
           {
             errno = ENOMEM ;
@@ -895,18 +898,23 @@ static void script_run (scriptelem_t const *script, unsigned int scriptlen, char
   size_t hlen = 0 ;
   char hstamp[32] ;
   char tstamp[TIMESTAMP+1] ;
-  if (gflags & 1)
+  if (gflags & 3)
   {
-    timestamp_g(tstamp) ;
-    tstamp[TIMESTAMP] = ' ' ;
-  }
-  if (gflags & 2)
-  {
-    localtmn_t l ;
-    localtmn_from_tain_g(&l, 1) ;
-    hlen = localtmn_fmt(hstamp, &l) ;
-    hstamp[hlen++] = ' ' ;
-    hstamp[hlen++] = ' ' ;
+    tain_t now ;
+    tain_wallclock_read(&now) ;
+    if (gflags & 1)
+    {
+      timestamp_fmt(tstamp, &now) ;
+      tstamp[TIMESTAMP] = ' ' ;
+    }
+    if (gflags & 2)
+    {
+      localtmn_t l ;
+      localtmn_from_tain(&l, &now, 1) ;
+      hlen = localtmn_fmt(hstamp, &l) ;
+      hstamp[hlen++] = ' ' ;
+      hstamp[hlen++] = ' ' ;
+    }
   }
   
   for (; i < scriptlen ; i++)
@@ -1141,14 +1149,17 @@ static inline void handle_signals (void)
 int main (int argc, char const *const *argv)
 {
   unsigned int sellen, actlen, scriptlen ;
-  unsigned int linelimit = 0, gflags = 0, compat_gflags = 0 ;
+  unsigned int linelimit = 8192 ;
+  unsigned int notif = 0 ;
+  unsigned int gflags = 0 ;
+  unsigned int compat_gflags = 0 ;
   int flagblock = 0 ;
   PROG = "s6-log" ;
   {
     subgetopt_t l = SUBGETOPT_ZERO ;
     for (;;)
     {
-      int opt = subgetopt_r(argc, argv, "qvbptel:", &l) ;
+      int opt = subgetopt_r(argc, argv, "qvbptel:d:", &l) ;
       if (opt == -1) break ;
       switch (opt)
       {
@@ -1159,6 +1170,11 @@ int main (int argc, char const *const *argv)
         case 't' : gflags |= 1 ; compat_gflags |= 1 ; break ;
         case 'e' : gflags |= 1 ; compat_gflags |= 2 ; break ;
         case 'l' : if (!uint0_scan(l.arg, &linelimit)) dieusage() ; break ;
+        case 'd' :
+          if (!uint0_scan(l.arg, &notif)) dieusage() ;
+          if (notif < 3) strerr_dief1x(100, "notification fd must be 3 or more") ;
+          if (fcntl(notif, F_GETFD) < 0) strerr_dief1sys(100, "invalid notification fd") ;
+          break ;
         default : dieusage() ;
       }
     }
@@ -1168,7 +1184,8 @@ int main (int argc, char const *const *argv)
   if (linelimit && linelimit < LINELIMIT_MIN) linelimit = LINELIMIT_MIN ;
   if (compat_gflags && verbosity) strerr_warnw1x("options -t and -e are deprecated") ;
   if (!fd_sanitize()) strerr_diefu1sys(111, "ensure stdin/stdout/stderr are open") ;
-  if (!tain_now_g() && verbosity) strerr_warnwu1sys("read current time - timestamps may be wrong for a while") ;
+  if (!tain_now_set_stopwatch_g() && verbosity)
+    strerr_warnwu1sys("set monotonic clock and read current time - timestamps may be wrong for a while") ;
   if (ndelay_on(0) < 0) strerr_diefu3sys(111, "set std", "in", " non-blocking") ;
   if (ndelay_on(1) < 0) strerr_diefu3sys(111, "set std", "out", " non-blocking") ;
   script_firstpass(argv, &sellen, &actlen, &scriptlen, &gflags) ;
@@ -1194,6 +1211,11 @@ int main (int argc, char const *const *argv)
         strerr_diefu1sys(111, "selfpipe_trapset") ;
     }
     x[0].events = IOPAUSE_READ ;
+    if (notif)
+    {
+      fd_write(notif, "\n", 1) ;
+      fd_close(notif) ;
+    }
 
     for (;;)
     {
