@@ -10,6 +10,9 @@
 #include <errno.h>
 #include <signal.h>
 #include <regex.h>
+
+#include <skalibs/posixplz.h>
+#include <skalibs/posixishard.h>
 #include <skalibs/types.h>
 #include <skalibs/allreadwrite.h>
 #include <skalibs/sgetopt.h>
@@ -526,7 +529,7 @@ static int makere (regex_t *re, char const *s, char const *var)
   size_t varlen = strlen(var) ;
   if (str_start(s, var) && (s[varlen] == '='))
   {
-    int r = regcomp(re, s + varlen + 1, REG_EXTENDED | REG_NOSUB) ;
+    int r = skalibs_regcomp(re, s + varlen + 1, REG_EXTENDED | REG_NOSUB) ;
     if (r)
     {
       if (verbosity)
@@ -544,7 +547,7 @@ static int makere (regex_t *re, char const *s, char const *var)
 
 static void defaultre (regex_t *re)
 {
-  int r = regcomp(re, ".^", REG_EXTENDED | REG_NOSUB) ;
+  int r = skalibs_regcomp(re, ".^", REG_EXTENDED | REG_NOSUB) ;
   if (r)
   {
     char buf[256] ;
@@ -759,6 +762,9 @@ int main (int argc, char const *const *argv, char const *const *envp)
       fd_write(1, "\n", 1) ;
       fd_close(1) ;
     }
+
+    /* We are long-lived and have to check absolute fd deadlines,
+       so we purposefully remain in wallclock mode. */
     tain_now_g() ;
 
     for (;;)
