@@ -1,10 +1,12 @@
 /* ISC license. */
 
 #include <errno.h>
+
+#include <skalibs/posixishard.h>
 #include <skalibs/allreadwrite.h>
-#include <skalibs/error.h>
 #include <skalibs/tai.h>
 #include <skalibs/unixmessage.h>
+
 #include <s6/s6-fdholder.h>
 
 int s6_fdholder_delete (s6_fdholder_t *a, char const *id, tain_t const *deadline, tain_t *stamp)
